Learn R Programming

mRchmadness (version 1.0.0)

bradley.terry: Fit a Bradley-Terry model on game score data

Description

Fit a Bradley-Terry model on game score data

Usage

bradley.terry(games)

Arguments

games
data.frame with the following columns: game.id, home.id, away.id, home.score, away.score, neutral, ot (matched by output of scrape.game.results)

Value

matrix of win probabilities, with rows and columns labeled by team. Each entry gives the probability of the team corresponding to that row beating the team corresponding to that column.

Examples

Run this code
  prob = bradley.terry(games = games.men.2017)

Run the code above in your browser using DataLab