Learn R Programming

mRchmadness (version 1.0.0)

pred.538.women.2017: 2017 Women's March Madness 538 Win Probability Predictions

Description

This dataset contains the win probabilities forecasted by the website FiveThirtyEight for the Women's March Madness tournament of the 2016-2017 season. The columns are the names of the teams, and FiveThirtyEight's projected probability of reaching each round.

Arguments

Format

data frame with 64 rows and 7 variables