Learn R Programming

mRchmadness (version 1.0.0)

pred.pop.men.2016: 2016 March Madness Men's Population Pick Distribution

Description

This dataset contains the percent of brackets submitted to ESPN that include each of the 64 teams in Men's March Madness 2016 reaching and winning in each successive round of the tournament.

Arguments

Format

data frame with 64 rows and 7 variables