Learn R Programming

mRchmadness (version 1.0.0)

pred.pop.men.2017: 2017 March Madness Population Pick Distribution

Description

This dataset contains the percent of brackets submitted to ESPN that include each of the 64 teams in March Madness 2017 reaching and winning in each successive round of the tournament.

Arguments

Format

data frame with 64 rows and 7 variables