Learn R Programming

mRchmadness (version 1.0.0)

scrape.population.distribution: Scrape the average rate of teams being picked to win across all ESPN brackets

Description

Scrape the average rate of teams being picked to win across all ESPN brackets

Usage

scrape.population.distribution(year, sex = c("mens", "womens"))

Arguments

year
the numeric year to scrape, either 2016 or 2017
sex
either 'mens' or 'womens'

Value

data.frame giving percentage of population picking each team in each round

Examples

Run this code
populationDistribution = scrape.population.distribution(2017)

Run the code above in your browser using DataLab