Learn R Programming

mRchmadness (version 1.0.0)

teams.women: NCAA Women's Basketball Teams

Description

This dataset the names of each team in NCAA Women's Basketball from ESPN, their ESPN team id, their name as it appears on the Who Picked Whom, and their FiveThirtyEight name.

Arguments

Format

data frame with 349 rows and 4 variables