bradley.terry: Fit a Bradley-Terry model on game score data
Description
Fit a Bradley-Terry model on game score data
Usage
bradley.terry(games)
Arguments
games
data.frame with the following columns: game.id, home.id,
away.id, home.score, away.score, neutral, ot (matched by output of
scrape.game.results)
Value
matrix of win probabilities, with rows and columns labeled by team.
Each entry gives the probability of the team corresponding to that row
beating the team corresponding to that column.