Rdocumentation
powered by
Learn R Programming
mRchmadness (version 1.0.0)
scrape.teams: Scrape the team names and ids from the ESPN NCAA MBB index
Description
Scrape the team names and ids from the ESPN NCAA MBB index
Usage
scrape.teams(sex)
Arguments
sex
either 'mens' or 'womens'
Value
data.frame of team names and ids